@@ -130,19 +130,19 @@ class ClinicalQualityMeasure138v6(ClinicalQualityMeasure):
     opportunities for improvement. The overall rate (rate/population 3) can be utilized to compare
     performance to prior published versions of this measure.
 
-    More information: https://ecqi.healthit.gov/ecqm/measures/cms138v6
+    More information: https://ecqi.healthit.gov/sites/default/files/ecqm/measures/CMS138v6.html
     """
 
     class Meta:
         title = 'Preventive Care and Screening: Tobacco Use: Screening and Cessation Intervention'
-        version = '2019-04-03v1'
+        version = '2022-01-31v1'
         default_display_interval_in_days = 365 * 2
 
         description = (
             'Patients aged 18 years and older who have not been screened for tobacco use OR '
             'who have not received tobacco cessation intervention if identified as a tobacco user.'
         )
-        information = 'https://ecqi.healthit.gov/ecqm/measures/cms138v6'
+        information = 'https://ecqi.healthit.gov/sites/default/files/ecqm/measures/CMS138v6.html'
 
         identifiers = ['CMS138v6']
 
@@ -205,10 +205,8 @@ class ClinicalQualityMeasure138v6(ClinicalQualityMeasure):
         if not self.tobacco_use_screening_user:
             return None
         # @ide-format:off
-        medication = (self.patient
-                          .medications
-                          .find(TobaccoUseCessationPharmacotherapy)
-                          .intersects(self.timeframe, still_active=self.patient.active_only))  # yapf: disable
+        medication = (self.patient .medications .find(TobaccoUseCessationPharmacotherapy) .intersects(
+            self.timeframe, still_active=self.patient.active_only))  # yapf: disable
         # @ide-format:on
         if medication:
             start = arrow.get(self.tobacco_use_screening_user.date())
@@ -281,6 +279,15 @@ class ClinicalQualityMeasure138v6(ClinicalQualityMeasure):
         non_user = interviews.find(TobaccoNonUser).last()
         return arrow.get(
             screening['noteTimestamp']) if screening and screening == non_user else None
+    
+    def protocol_has_context_guidance(self) -> bool:
+        if self.context == CONTEXT_GUIDANCE:
+            return True
+
+        if hasattr(self.context, 'get'):
+            return True
+
+        return False
 
     def in_initial_population(self) -> bool:
         """
@@ -288,7 +295,7 @@ class ClinicalQualityMeasure138v6(ClinicalQualityMeasure):
         least one preventive visit during the measurement period
         """
         result = (self.patient.age_at(self.timeframe.end) >= self.MINIMUM_AGE and
-                  (self.context == CONTEXT_GUIDANCE or
+                  (self.protocol_has_context_guidance() or
                    self.patient.has_visit_within(self.timeframe,
                                                  (AnnualWellnessVisit |
                                                   PreventiveCareServicesEstablishedOfficeVisit18AndUp |
