@@ -19,7 +19,7 @@ class TestClinicalQualityMeasure125v6(SDKBaseTest):
         self.assertEqual(expected, ClinicalQualityMeasure125v6._meta.description)
 
     def test_information(self):
-        expected = 'https://ecqi.healthit.gov/ecqm/measures/cms125v6'
+        expected = 'https://ecqi.healthit.gov/sites/default/files/ecqm/measures/CMS125v6.html'
         self.assertEqual(expected, ClinicalQualityMeasure125v6._meta.information)
 
     def test_enabled(self):
