@@ -26,7 +26,7 @@ class ClinicalQualityMeasure130v6Test(SDKBaseTest):
         self.assertEqual(expected, ClinicalQualityMeasure130v6._meta.description)
 
     def test_information(self):
-        expected = 'https://ecqi.healthit.gov/ecqm/measures/cms130v6'
+        expected = 'https://ecqi.healthit.gov/sites/default/files/ecqm/measures/CMS130v6.html'
         self.assertEqual(expected, ClinicalQualityMeasure130v6._meta.information)
 
     def test_enabled(self):
