@@ -6,8 +6,7 @@ from canvas_workflow_kit import settings
 
 # flake8: noqa
 from canvas_workflow_kit.builtin_cqms.cms138v6_preventive_care_and_screening_tobacco_use_screening_and_cessation_intervention import (
-    ClinicalQualityMeasure138v6
-)
+    ClinicalQualityMeasure138v6)
 from canvas_workflow_kit.patient_recordset import (
     BillingLineItemRecordSet,
     InstructionRecordSet,
@@ -36,7 +35,7 @@ class TestClinicalQualityMeasure138v6(SDKBaseTest):
         self.assertEqual(expected, ClinicalQualityMeasure138v6._meta.description)
 
     def test_information(self):
-        expected = 'https://ecqi.healthit.gov/ecqm/measures/cms138v6'
+        expected = 'https://ecqi.healthit.gov/sites/default/files/ecqm/measures/CMS138v6.html'
         self.assertEqual(expected, ClinicalQualityMeasure138v6._meta.information)
 
     def test_change_types(self):
