@@ -31,7 +31,7 @@ class TestClinicalQualityMeasure138v6p2(SDKBaseTest):
         self.assertEqual(expected, ClinicalQualityMeasure138v6p2._meta.description)
 
     def test_information(self):
-        expected = 'https://ecqi.healthit.gov/ecqm/measures/cms138v6'
+        expected = 'https://ecqi.healthit.gov/sites/default/files/ecqm/measures/CMS138v6.html'
         self.assertEqual(expected, ClinicalQualityMeasure138v6p2._meta.information)
 
     def test_change_types(self):
