@@ -167,6 +167,9 @@ class PatientRecordSet:
         if 'coding' in item:
             return item['coding']
 
+        if 'substance' in item:
+            return item['substance']['coding']
+
         return []
 
     def validated(self):
